@@ -2,5 +2,5 @@
 
 source $(dirname $0)/test.inc.sh
 
-po2txt --progress=none $one $out
+python $PYTHON_ARGS $(which po2txt) --progress=none $one $out
 check_results
