@@ -1,4 +1,4 @@
-from copy import deepcopy
+from copy import copy, deepcopy
 
 from lxml import etree
 
@@ -57,10 +57,7 @@ class TestAndroidResourceUnit(test_monolingual.TestMonolingualUnit):
 
     def test_escape_message_with_newline_in_xml(self):
         string = "message\n\nwith newline in xml\n"
-        xml = (
-            '<string name="teststring">message\\n\\nwith newline in xml\\n'
-            "</string>\n"
-        )
+        xml = '<string name="teststring">message\\n\\nwith newline in xml\\n</string>\n'
         self.__check_escape(string, xml)
 
     def test_escape_twitter(self):
@@ -111,8 +108,7 @@ class TestAndroidResourceUnit(test_monolingual.TestMonolingualUnit):
     def test_escape_html_code_quote_newline(self):
         string = "some \n<b>html code</b> 'here'"
         xml = (
-            "<string name=\"teststring\">some \\n<b>html code</b> \\'here\\'"
-            "</string>\n"
+            "<string name=\"teststring\">some \\n<b>html code</b> \\'here\\'</string>\n"
         )
         self.__check_escape(string, xml)
 
@@ -296,8 +292,7 @@ class TestAndroidResourceUnit(test_monolingual.TestMonolingualUnit):
     def test_parse_link(self):
         string = '<a href="http://example.net">link</a>'
         xml = (
-            '<string name="teststring"><a href="http://example.net">link'
-            "</a></string>\n"
+            '<string name="teststring"><a href="http://example.net">link</a></string>\n'
         )
         self.__check_parse(string, xml)
 
@@ -491,6 +486,52 @@ class TestAndroidResourceUnit(test_monolingual.TestMonolingualUnit):
         xml = '<string name="teststring">"a\nb\tc d"</string>'
         self.__check_parse(string, xml)
 
+    def test_parse_quoted_escaped_percent(self):
+        self.__check_parse(
+            """You are about to remove "%s" from your library""",
+            r"""<string name="remove_manga">You are about to remove \"%s\" from your library</string>""",
+        )
+
+    def test_parse_quoted_percent(self):
+        self.__check_parse(
+            """You are about to remove %s from your library""",
+            """<string name="remove_manga">You are about to remove "%s" from your library</string>""",
+        )
+
+    def test_parse_quoted_quote(self):
+        self.__check_parse(
+            """You are about to remove "%s" from your library""",
+            r"""<string name="remove_manga">You are about to "remove \"%s\" from" your library</string>""",
+        )
+
+    def test_parse_unparied_quote(self):
+        self.__check_parse(
+            """You can view it here soon: %s""",
+            """<string name="cmd_camera_response_success">"You can view it here soon: %s</string>""",
+        )
+        self.__check_parse(
+            'You can view it here soon: %s"',
+            """<string name="cmd_camera_response_success">You can view it here soon: %s"</string>""",
+        )
+
+    def test_parse_escape_slash(self):
+        self.__check_parse(
+            """Přechod na novější verzi databáze účtu \\<g id="account">%s</g>\\""",
+            r"""<string name="upgrade_database_format">Přechod na novější verzi databáze účtu \\<g id="account">%s</g>\\</string>""",
+        )
+
+    def test_parse_escape_ignored(self):
+        self.__check_parse(
+            """Přechod na novější verzi databáze účtu \\<g id="account">%s</g>""",
+            r"""<string name="upgrade_database_format">Přechod na novější verzi databáze účtu \\<g id="account">%s</g>\x</string>""",
+        )
+
+    def test_parse_escaped_quote_end(self):
+        self.__check_parse(
+            'No file %1$s found in archive "%2$s"',
+            r"""<string name="restore_backup_file_not_found">No file %1$s found in archive \"%2$s\"</string>""",
+        )
+
 
 class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
     StoreClass = aresource.AndroidResourceFile
@@ -558,7 +599,8 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
         content = b"""<?xml version="1.0" encoding="utf-8"?>
 <resources>
     <string name="test">Test</string>
-</resources>"""
+</resources>
+"""
         store = self.StoreClass()
         store.parse(content)
         assert bytes(store) == content
@@ -577,7 +619,8 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
 <resources>
     <string name="test">Test</string>
     <string name="other">Test</string>
-</resources>"""
+</resources>
+"""
         store = self.StoreClass()
         store.parse(content)
         otherstore = self.StoreClass()
@@ -593,7 +636,8 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
 <resources>
     <string name="app_name">&appName;</string>
     <string name="app_core">&appName; Core</string>
-</resources>"""
+</resources>
+"""
         store = self.StoreClass()
         store.parse(content)
         assert store.units[0].source == "&appName;"
@@ -610,7 +654,8 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
 <resources>
     <string name="app_name">&appName;</string>
     <string name="app_core">&appName; Core</string>
-</resources>"""
+</resources>
+"""
         store = self.StoreClass()
         store.parse(content.encode())
         store.units[0].target = "&appName;"
@@ -626,7 +671,8 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
 ]>
 <resources>
     <string name="privacy_policy"><u><a href="&url_privacy_policy;">Datenschutzerklärung</a></u></string>
-</resources>""".encode()
+</resources>
+""".encode()
         store = self.StoreClass()
         store.parse(content)
         assert bytes(store) == content
@@ -639,7 +685,8 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
         <item quantity="few"><xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2" id="count">%d</xliff:g> dny</item>
         <item quantity="other"><xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2" id="count">%d</xliff:g> dnu</item>
     </plurals>
-</resources>"""
+</resources>
+"""
         store = self.StoreClass()
         store.targetlanguage = "cs"
         store.parse(content)
@@ -652,7 +699,7 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
         )
         assert bytes(store) == content
 
-    def test_entity_add(self, edit=True):
+    def entity_add(self, *, edit: bool):
         content = """<?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE resources [
 <!ENTITY appName "Zkouška">
@@ -660,7 +707,8 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
 <resources>
     <string name="app_name">&appName;</string>
     <string name="app_core">&appName; Core</string>
-</resources>"""
+</resources>
+"""
         store = self.StoreClass()
         store.parse(content.encode())
         second = self.StoreClass()
@@ -677,14 +725,18 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
         # The new store should have same content
         assert bytes(second).decode() == content
 
+    def test_entity_add_edit(self):
+        self.entity_add(edit=True)
+
     def test_entity_add_noedit(self):
-        self.test_entity_add(edit=False)
+        self.entity_add(edit=False)
 
     def test_markup_remove(self):
         template = """<?xml version="1.0" encoding="utf-8"?>
 <resources>
     <string name="privacy_policy"><u>Datenschutzerklärung</u></string>
-</resources>"""
+</resources>
+"""
         content = template.encode("utf-8")
         newcontent = template.replace("<u>", "").replace("</u>", "").encode("utf-8")
         store = self.StoreClass()
@@ -698,7 +750,8 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
 <resources>
     <!--Multimedia tab-->
     <string name="id">Multimedia tab</string>
-</resources>"""
+</resources>
+"""
         content = template.encode("utf-8")
         newcontent = template.replace(">Multimedia tab<", ">Other <b>tab</b><").encode(
             "utf-8"
@@ -718,7 +771,8 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
         <item quantity="many"><xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2" id="count">%d</xliff:g> dnu</item>
         <item quantity="other"><xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2" id="count">%d</xliff:g> dnu</item>
     </plurals>
-</resources>"""
+</resources>
+"""
         store = self.StoreClass()
         store.targetlanguage = "ru"
         store.parse(content)
@@ -735,7 +789,8 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
         template = """<?xml version="1.0" encoding="utf-8"?>
 <resources>
     <string name="id">Test</string>
-</resources>"""
+</resources>
+"""
         content = template.encode()
         newcontent = template.replace(
             ">Test<", ">Test <b>string</b> with \\u0020space<"
@@ -753,11 +808,13 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
         original = """<?xml version="1.0" encoding="utf-8"?>
 <resources>
     <string name="id">Test: <xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">%s</xliff:g></string>
-</resources>"""
+</resources>
+"""
         expected = """<?xml version="1.0" encoding="utf-8"?>
 <resources>
     <string name="id">Other: <xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">%s</xliff:g></string>
-</resources>"""
+</resources>
+"""
         origstore = self.StoreClass()
         origstore.parse(original.encode())
         store = self.StoreClass()
@@ -773,11 +830,13 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
         original = """<?xml version="1.0" encoding="utf-8"?>
 <resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
     <string name="id">Test</string>
-</resources>"""
+</resources>
+"""
         expected = """<?xml version="1.0" encoding="utf-8"?>
 <resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
     <string name="id">Test: <xliff:g>%s</xliff:g></string>
-</resources>"""
+</resources>
+"""
         store = self.StoreClass()
         store.parse(original.encode())
         assert bytes(store).decode() == original
@@ -794,7 +853,8 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
         <item quantity="one">%d visitor</item>
         <item quantity="other">%d visitors</item>
     </plurals>
-</resources>"""
+</resources>
+"""
         store = self.StoreClass()
         store.targetlanguage = "zh-rHK"
         store.parse(content.encode())
@@ -806,7 +866,8 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
     <plurals name="vms_num_visitors">
         <item quantity="other">%d 訪客</item>
     </plurals>
-</resources>"""
+</resources>
+"""
         )
 
     def test_edit_plural_b_zh_hk(self):
@@ -816,7 +877,8 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
         <item quantity="one">%d visitor</item>
         <item quantity="other">%d visitors</item>
     </plurals>
-</resources>"""
+</resources>
+"""
         store = self.StoreClass()
         store.targetlanguage = "b+zh+Hant+HK"
         store.parse(content.encode())
@@ -828,7 +890,8 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
     <plurals name="vms_num_visitors">
         <item quantity="other">%d 訪客</item>
     </plurals>
-</resources>"""
+</resources>
+"""
         )
 
     def test_missing_plural(self):
@@ -838,7 +901,8 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
         <item quantity="one">%d visitor</item>
         <item quantity="other">%d visitors</item>
     </plurals>
-</resources>"""
+</resources>
+"""
         store = self.StoreClass()
         store.targetlanguage = "fr"
         store.parse(content.encode())
@@ -853,7 +917,8 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
     <string name="test2">Test</string>
     <!-- Third -->
     <string name="test3">Test2</string>
-</resources>"""
+</resources>
+"""
         store = self.StoreClass()
         store.parse(content.encode())
         assert len(store.units) == 3
@@ -867,7 +932,8 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
     <string name="test1">Test</string>
     <!-- Third -->
     <string name="test3">Test2</string>
-</resources>"""
+</resources>
+"""
         )
 
     def test_cdata(self):
@@ -886,7 +952,8 @@ files</strong> on the storage.</p>
         content = f"""<?xml version="1.0" encoding="utf-8"?>
 <resources>
     <string name="dialog_storage_permission_info" formatted="false">{body}</string>
-</resources>"""
+</resources>
+"""
         store = self.StoreClass()
         store.parse(content.encode())
         assert len(store.units) == 1
@@ -900,7 +967,10 @@ files</strong> on the storage.</p>
         content = f"""<?xml version="1.0" encoding="utf-8"?>
 <resources>
     <string name="service_terms_agreement_notice">{body}</string>
-</resources>"""
+</resources>
+"""
+
+        # Verify round trip
         store = self.StoreClass()
         store.parse(content.encode())
         assert len(store.units) == 1
@@ -909,12 +979,32 @@ files</strong> on the storage.</p>
         store.units[0].target = body
         assert bytes(store).decode() == content
 
+        # Verify copying unit to new store
+        newstore = self.StoreClass()
+        newstore.addunit(copy(store.units[0]), new=True)
+        assert bytes(newstore).decode() == content
+        newstore.units[0].target = body
+        assert bytes(newstore).decode() == content
+
+        # Verify creating unit from scratch
+        addstore = self.StoreClass()
+        unit = addstore.UnitClass(body)
+        unit.setid("service_terms_agreement_notice")
+        unit.target = body
+        addstore.addunit(unit, new=True)
+        assert len(addstore.units) == 1
+        assert addstore.units[0].target == body
+        assert bytes(addstore).decode() == content
+        addstore.units[0].target = body
+        assert bytes(addstore).decode() == content
+
     def test_prefix(self):
         body = "&lt; <b>body</b>"
         content = f"""<?xml version="1.0" encoding="utf-8"?>
 <resources>
     <string name="test">{body}</string>
-</resources>"""
+</resources>
+"""
         store = self.StoreClass()
         store.parse(content.encode())
         assert len(store.units) == 1
@@ -925,7 +1015,8 @@ files</strong> on the storage.</p>
         content = """<?xml version="1.0" encoding="utf-8"?>
 <resources>
     <string name="calendar_permission_required"><i>{app_name}</i> צרכה רשות לגשת ליומן שלך, על מנת ליצור תוכניות עבור עסקאות עתידיות חוזרות.</string>
-</resources>"""
+</resources>
+"""
         store = self.StoreClass()
         store.parse(content.encode())
         assert len(store.units) == 1
@@ -997,7 +1088,8 @@ class TestMOKOResourceFile(test_monolingual.TestMonolingualStore):
         <item quantity="one">%d visitor</item>
         <item quantity="other">%d visitors</item>
     </plural>
-</resources>"""
+</resources>
+"""
         store = self.StoreClass()
         store.parse(content.encode())
         assert store.units[0].target == multistring(["%d visitor", "%d visitors"])
@@ -1012,5 +1104,6 @@ class TestMOKOResourceFile(test_monolingual.TestMonolingualStore):
     <plural name="vms_num_visitors">
         <item quantity="other">%d 訪客</item>
     </plural>
-</resources>"""
+</resources>
+"""
         )
