@@ -23,7 +23,7 @@ def givefile(filename, content):
 class BaseTestFactory:
     def setup_method(self, method):
         """Sets up a test directory."""
-        self.testdir = "%s_testdir" % (self.__class__.__name__)
+        self.testdir = f"{self.__class__.__name__}_testdir"
         self.cleardir(self.testdir)
         os.mkdir(self.testdir)
 
