@@ -289,18 +289,18 @@ class TestXLIFFfile(test_base.TestTranslationStore):
 
         unit.addnote("Please buy bread")
         assert unit.getnotes() == "Please buy bread"
-        notenodes = unit.xmlelement.findall(".//%s" % unit.namespaced("note"))
+        notenodes = unit.xmlelement.findall(".//{}".format(unit.namespaced("note")))
         assert len(notenodes) == 1
 
         unit.addnote("Please buy milk", origin="Mom")
-        notenodes = unit.xmlelement.findall(".//%s" % unit.namespaced("note"))
+        notenodes = unit.xmlelement.findall(".//{}".format(unit.namespaced("note")))
         assert len(notenodes) == 2
         assert "from" not in notenodes[0].attrib
         assert notenodes[1].get("from") == "Mom"
         assert unit.getnotes(origin="Mom") == "Please buy milk"
 
         unit.addnote("Don't forget the beer", origin="Dad")
-        notenodes = unit.xmlelement.findall(".//%s" % unit.namespaced("note"))
+        notenodes = unit.xmlelement.findall(".//{}".format(unit.namespaced("note")))
         assert len(notenodes) == 3
         assert notenodes[1].get("from") == "Mom"
         assert notenodes[2].get("from") == "Dad"
