@@ -61,8 +61,7 @@ class rerc:
         if not addnl:
             yield "    "
         # Strip extra \r from \r\n which is left in the comment by the parser
-        if comment.endswith("\r"):
-            comment = comment[:-1]
+        comment = comment.removesuffix("\r")
         yield comment
 
     def convert_caption(self, toks, name):
@@ -122,7 +121,7 @@ class rerc:
             # collect initial quoted items to form msgid
             i = 1
             while isinstance(c[i], str) and c[i].startswith(("'", '"')):
-                i = i + 1
+                i += 1
             msgid = "".join(cn[1:-1] for cn in c[1:i])
 
             name = rc.generate_dialog_control_name(
@@ -303,13 +302,13 @@ class rerc:
             return list(self.convert_language(s, loc, toks))
 
         if toks.block_type:
-            if toks.block_type in ("DIALOGEX", "DIALOG"):
+            if toks.block_type in {"DIALOGEX", "DIALOG"}:
                 return list(self.convert_dialog(s, loc, toks))
 
             if toks.block_type == "STRINGTABLE":
                 return list(self.convert_string_table(s, loc, toks))
 
-            if toks.block_type in ("MENU", "MENUEX"):
+            if toks.block_type in {"MENU", "MENUEX"}:
                 return list(self.convert_menu(s, loc, toks))
 
         return toks
@@ -356,6 +355,7 @@ def convertrc(
     lang=None,
     sublang=None,
     outputthreshold=None,
+    output_charset=None,
 ):
     inputstore = po.pofile(inputfile)
 
@@ -368,11 +368,14 @@ def convertrc(
         raise ValueError("must have template file for rc files")
     convertor = rerc(templatefile, charset, lang, sublang)
     outputrclines = convertor.convertstore(inputstore, includefuzzy)
-    try:
-        outputfile.write(outputrclines.encode("cp1252"))
-    except UnicodeEncodeError:
-        outputfile.write(codecs.BOM_UTF16_LE)
-        outputfile.write(outputrclines.encode("utf-16-le"))
+    if output_charset == "auto":
+        try:
+            outputfile.write(outputrclines.encode("cp1252"))
+        except UnicodeEncodeError:
+            outputfile.write(codecs.BOM_UTF16_LE)
+            outputfile.write(outputrclines.encode("utf-16-le"))
+    else:
+        outputfile.write(outputrclines.encode(output_charset))
     outputfile.close()
     templatefile.close()
     return 1
@@ -390,7 +393,15 @@ def main(argv=None):
         "--charset",
         dest="charset",
         default=defaultcharset,
-        help="charset to use to decode the RC files (default: %s)" % defaultcharset,
+        help=f"charset to use to decode the template RC files (default: {defaultcharset})",
+        metavar="CHARSET",
+    )
+    parser.add_option(
+        "",
+        "--charset-output",
+        dest="output_charset",
+        default="auto",
+        help="charset to use to encode the RC file (default: auto)",
         metavar="CHARSET",
     )
     parser.add_option(
@@ -402,10 +413,11 @@ def main(argv=None):
         "--sublang",
         dest="sublang",
         default=defaultsublang,
-        help="SUBLANG entry (default: %s)" % defaultsublang,
+        help=f"SUBLANG entry (default: {defaultsublang})",
         metavar="SUBLANG",
     )
     parser.passthrough.append("charset")
+    parser.passthrough.append("output_charset")
     parser.passthrough.append("lang")
     parser.passthrough.append("sublang")
     parser.add_threshold_option()
