@@ -16,7 +16,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""Convert Gettext PO localization files to Qt Linguist (.ts) files.
+"""
+Convert Gettext PO localization files to Qt Linguist (.ts) files.
 
 See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/commands/ts2po.html
 for examples and usage instructions.
@@ -28,11 +29,8 @@ from translate.storage import po, ts2
 class po2ts:
     @staticmethod
     def convertstore(inputstore, outputfile, templatefile=None, context=None):
-        """converts a .po file to .ts format (using a template .ts file if given)"""
-        if templatefile is None:
-            tsfile = ts2.tsfile()
-        else:
-            tsfile = ts2.tsfile(templatefile)
+        """Converts a .po file to .ts format (using a template .ts file if given)."""
+        tsfile = ts2.tsfile() if templatefile is None else ts2.tsfile(templatefile)
         for inputunit in inputstore.units:
             if inputunit.isheader() or inputunit.isblank():
                 continue
@@ -58,7 +56,7 @@ class po2ts:
 
 
 def convertpo(inputfile, outputfile, templatefile, context):
-    """reads in stdin using fromfileclass, converts using convertorclass, writes to stdout"""
+    """Reads in stdin using fromfileclass, converts using convertorclass, writes to stdout."""
     inputstore = po.pofile(inputfile)
     if inputstore.isempty():
         return 0
