@@ -35,11 +35,12 @@ from translate.storage import base, lisa
 WHITESPACE = {" ", "\n", "\t"}  # Whitespace that we collapse.
 ESCAPE_NEWLINE = {"n", "N"}
 ESCAPE_TAB = {"t", "T"}
-ESCAPE_PLAIN = {" ", '"', "'", "@", "?"}
+ESCAPE_PLAIN = {" ", '"', "'", "@", "?", "\\"}
 MULTIWHITESPACE = re.compile(r"[ \n\t]{2}(?!\\n)")
-QUOTED_STRING = re.compile(r'("[^"]*")')
+QUOTED_STRING = re.compile(r'((?<!\\)"(?:\\"|[^"])*(?<!\\)")')
 UNICODE_ESCAPE = re.compile(r"\\u([a-fA-F0-9]{4})")
 CHAR_ESCAPE = re.compile(r"\\(.)")
+WHITESPACE_RE = re.compile(r"\s+")
 
 ESCAPE_TRANSLATE = str.maketrans(
     {
@@ -104,6 +105,14 @@ class DecodingXMLParser:
         # All others, remove, like Android does as well.
         return ""
 
+    @staticmethod
+    def strip_part(text: str) -> str:
+        if text.startswith('"'):
+            # Missing closing quote is gracefully ignored
+            return text.removeprefix('"').removesuffix('"')
+        # Consolidate whitespace
+        return WHITESPACE_RE.sub(" ", text)
+
     @classmethod
     def process_string(cls, content: str) -> tuple[str, bool, bool]:
         # Skip processing for a blank string
@@ -118,10 +127,7 @@ class DecodingXMLParser:
         cleanup_end = not parts[-1].startswith('"')
 
         # Collapse whitespace
-        stripped_parts = [
-            re.sub(r"\s+", " ", part) if not part.startswith('"') else part[1:-1]
-            for part in parts
-        ]
+        stripped_parts = [cls.strip_part(part) for part in parts]
         # Merge this back to a single string
         text = "".join(stripped_parts)
 
@@ -132,9 +138,9 @@ class DecodingXMLParser:
 
         # Detect escaping at the start and end of a string (we actually care only for
         # whitespace escapes, but detecting more does not matter)
-        if text and text[0] != unescaped_text[0]:
+        if text and unescaped_text and text[0] != unescaped_text[0]:
             cleanup_start = False
-        if text and text[-1] != unescaped_text[-1]:
+        if text and unescaped_text and text[-1] != unescaped_text[-1]:
             cleanup_end = False
 
         return unescaped_text, cleanup_start, cleanup_end
@@ -504,7 +510,7 @@ class AndroidResourceFile(lisa.LISAfile):
     bodyNode = "resources"
     XMLskeleton = """<?xml version="1.0" encoding="utf-8"?>
 <resources></resources>"""
-    XMLindent = {"indent": "    ", "leaves": {"string", "item"}}
+    XMLindent = {"indent": "    ", "leaves": {"string", "item"}, "trailing_eol": True}
     XMLuppercaseEncoding = False
 
     def initbody(self):
