@@ -54,7 +54,7 @@ def mounpack(filename="messages.mo"):
     """Helper to unpack Gettext MO files into a Python string."""
     with open(filename, "rb") as fh:
         s = fh.read()
-        print("\\x%02x" * len(s) % tuple(map(ord, s)))
+        return "\\x%02x" * len(s) % tuple(map(ord, s))
 
 
 def my_swap4(result):
@@ -72,12 +72,12 @@ def hashpjw(str_param):
     for s in str_param:
         if not s:
             break
-        hval = hval << 4
+        hval <<= 4
         hval += s
         g = hval & 0xF << (HASHWORDBITS - 4)
         if g != 0:
-            hval = hval ^ (g >> (HASHWORDBITS - 8))
-            hval = hval ^ g
+            hval ^= g >> HASHWORDBITS - 8
+            hval ^= g
     return hval
 
 
@@ -126,7 +126,7 @@ class mounit(base.TranslationUnit):
 
     def isheader(self):
         """Is this a header entry?."""
-        return self.source == ""
+        return not self.source
 
     def istranslatable(self):
         """Is this message translateable?."""
@@ -158,7 +158,7 @@ class mofile(poheader.poheader, base.TranslationStore):
             increment = 1 + (hash_value % (hash_size - 2))
             while hash_table[hash_cursor] != 0:
                 hash_cursor += increment
-                hash_cursor = hash_cursor % hash_size
+                hash_cursor %= hash_size
             hash_table[hash_cursor] = i + 1
 
         def lst_encode(lst, join_char=b""):
@@ -286,12 +286,12 @@ class mofile(poheader.poheader, base.TranslationStore):
             if b"\x04" in source:
                 context, source = source.split(b"\x04")
             # Still need to handle KDE comments
-            if source == "":
+            if not source:
                 charset = re.search(
-                    b"charset=([^\\s]+)", input[voffset : voffset + vlength]
+                    rb"charset=([^\s]+)", input[voffset : voffset + vlength]
                 )
                 if charset:
-                    self.encoding = charset.group(1)
+                    self.encoding = charset.group(1).decode()
             source = multistring([s.decode(self.encoding) for s in source.split(b"\0")])
             target = multistring(
                 [
