@@ -21,6 +21,8 @@ Contains general placeable implementations. That is placeables that does not
 fit into any other sub-category.
 """
 
+from __future__ import annotations
+
 import re
 
 from translate.storage.placeables.base import G, Ph, StringElem
@@ -34,7 +36,7 @@ __all__ = (
 )
 
 
-def regex_parse(cls, pstr):
+def regex_parse(cls, pstr: str) -> list[StringElem]:
     """
     A parser method to extract placeables from a string based on a regular
     expression. Use this function as the ``@parse()`` method of a placeable
@@ -76,7 +78,7 @@ class NumberPlaceable(Ph):
     """Placeable for numbers."""
 
     istranslatable = False
-    regex = re.compile("[-+]?[0-9]+([\u00a0.,][0-9]+)*")
+    regex = re.compile(r"[-+]?[0-9]+([\u00a0.,][0-9]+)*")
     parse = classmethod(regex_parse)
 
 
@@ -94,6 +96,7 @@ class QtFormattingPlaceable(Ph):
       - Place markers may be repeated
       - 'L' use a localised representation e.g. in a number
       - %% some in the wild to escape real %, not documented (not in regex)
+
     """
 
     iseditable = False
@@ -256,7 +259,7 @@ class PunctuationPlaceable(Ph):
     # is available on the translators keyboard.  Or easily expanded by their
     # configuration.
     regex = re.compile(
-        """([™©®]|          # Marks
+        r"""([™©®]|          # Marks
              [℃℉°]|          # Degree related
              [±πθ×÷−√∞∆Σ′″]| # Maths
              [‘’ʼ‚‛“”„‟]|    # Quote characters
