@@ -22,7 +22,7 @@ from urllib import parse
 from translate.storage import base, poheader
 from translate.storage.workflow import StateEnum as state
 
-msgid_comment_re = re.compile("_: (.*?)\n")
+msgid_comment_re = re.compile(r"_: (.*?)\n")
 
 
 def extract_msgid_comment(text):
