@@ -25,8 +25,8 @@ from translate import __version__
 from translate.misc.dictutils import cidict
 
 author_re = re.compile(r".*<\S+@\S+>.*\d{4,4}")
-nplural_re = re.compile("nplurals=(.+?);")
-plural_re = re.compile("plural=(.+?);?$")
+nplural_re = re.compile(r"nplurals=(.+?);")
+plural_re = re.compile(r"plural=(.+?);?$")
 
 default_header = {
     "Project-Id-Version": "PACKAGE VERSION",
@@ -414,7 +414,7 @@ class poheader:
                 incontrib = True
                 contriblines.append(line)
                 continue
-            if line == "" and incontrib:
+            if not line and incontrib:
                 incontrib = False
                 outcontrib = True
             if incontrib:
