@@ -188,12 +188,8 @@ class RubyYAMLUnit(YAMLUnit):
 
         tags = plural_tags.get(self._store.targetlanguage, plural_tags["en"])
 
-        strings = [str(s) for s in self.target.strings]
-
         # Sync plural_strings elements to plural_tags count.
-        if len(strings) < len(tags):
-            strings += [""] * (len(tags) - len(strings))
-        strings = strings[: len(tags)]
+        strings = self.sync_plural_count(self.target, tags)
 
         return CommentedMap(zip(tags, strings))
 
@@ -206,10 +202,13 @@ class RubyYAMLFile(YAMLFile):
     def preprocess(self, data):
         if isinstance(data, CommentedMap) and len(data) == 1:
             lang = next(iter(data.keys()))
-            self.settargetlanguage(lang)
+            # Handle blank values
             if data[lang] is None:
                 data[lang] = CommentedMap()
-            return data[lang]
+            # Do not try to parse string only, CommentedMap is dict as well
+            if isinstance(data[lang], dict):
+                self.settargetlanguage(lang)
+                return data[lang]
         return data
 
     def get_root_node(self):
@@ -223,7 +222,12 @@ class RubyYAMLFile(YAMLFile):
         if data and all(x in cldr_plural_categories for x in data):
             # Ensure we have correct plurals ordering.
             values = [data[item] for item in cldr_plural_categories if item in data]
-            yield (prev, multistring(values))
+
+            # Skip blank values (all plurals are None)
+            if not all(value is None for value in values):
+                # Use blank string insted of None here
+                yield (prev, multistring([value or "" for value in values]))
+
             return
 
         # Handle normal dict
