@@ -16,7 +16,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""Restructure Gettxt PO files produced by
+"""
+Restructure Gettxt PO files produced by
 :doc:`poconflicts </commands/poconflicts>` into the original directory tree
 for merging using :doc:`pomerge </commands/pomerge>`.
 
@@ -32,23 +33,21 @@ from translate.storage import po
 
 
 class SplitOptionParser(optrecurse.RecursiveOptionParser):
-    """a specialized Option Parser for posplit"""
+    """a specialized Option Parser for posplit."""
 
     def parse_args(self, args=None, values=None):
-        """parses the command line options, handling implicit input/output args"""
-        (options, args) = optrecurse.RecursiveOptionParser.parse_args(
-            self, args, values
-        )
+        """Parses the command line options, handling implicit input/output args."""
+        (options, args) = super().parse_args(args, values)
         if not options.output:
             self.error("Output file is rquired")
         return (options, args)
 
     def set_usage(self, usage=None):
-        """sets the usage string - if usage not given, uses getusagestring for each option"""
+        """Sets the usage string - if usage not given, uses getusagestring for each option."""
         if usage is None:
             self.usage = (
                 "%prog "
-                + " ".join([self.getusagestring(option) for option in self.option_list])
+                + " ".join(self.getusagestring(option) for option in self.option_list)
                 + "\n  "
                 + "input directory is searched for PO files with (poconflicts) comments, all entries are written to files in a directory structure for pomerge"
             )
@@ -56,7 +55,7 @@ class SplitOptionParser(optrecurse.RecursiveOptionParser):
             super().set_usage(usage)
 
     def recursiveprocess(self, options):
-        """recurse through directories and process files"""
+        """Recurse through directories and process files."""
         if not self.isrecursive(options.output, "output"):
             self.warning("Output directory does not exist. Attempting to create")
             try:
@@ -76,12 +75,11 @@ class SplitOptionParser(optrecurse.RecursiveOptionParser):
                 inputfiles = self.recurseinputfilelist(options)
             else:
                 inputfiles = self.recurseinputfiles(options)
+        elif options.input:
+            inputfiles = [os.path.basename(options.input)]
+            options.input = os.path.dirname(options.input)
         else:
-            if options.input:
-                inputfiles = [os.path.basename(options.input)]
-                options.input = os.path.dirname(options.input)
-            else:
-                inputfiles = [options.input]
+            inputfiles = [options.input]
         self.textmap = {}
         progress_bar = optrecurse.ProgressBar(options.progress, inputfiles)
         for inputpath in inputfiles:
@@ -90,16 +88,15 @@ class SplitOptionParser(optrecurse.RecursiveOptionParser):
                 success = self.processfile(options, fullinputpath)
             except Exception:
                 self.warning(
-                    "Error processing: input %s" % (fullinputpath),
+                    f"Error processing: input {fullinputpath}",
                     options,
                     sys.exc_info(),
                 )
                 success = False
             progress_bar.report_progress(inputpath, success)
-        del progress_bar
 
     def processfile(self, options, fullinputpath):
-        """process an individual file"""
+        """Process an individual file."""
         inputfile = self.openinputfile(options, fullinputpath)
         inputpofile = po.pofile(inputfile)
         for pounit in inputpofile.units:
